<?php

/*
 * This file contains your plug-in routines.
 * This file is required.
 */

/* 
 * Example how to switch between languages
 * Another idea would be to use this code:
 * include( './plugins/example/language/' . $config['language'] . '.php' );
 */
switch( $config['language'] ) {
	case 'german':
		$lang['aboutme_text'] = '&Uuml;ber mich';
		break;
	case 'english':
	default:
		$lang['aboutme_text'] = 'About me';
		break;
}

/*
 * Filter text. We turn the the first letter of the comment authors name
 * uppercase
 * Arguments: the name, string
 *  Every filter has one argument
 * Return value: The modified string
 *  You need to return the modified argument, otherwiese it will be lost
 */

function example_author_name_uc( $name = '' )
{
	/* You can load globals, if you need $config, $db, or whatever */
	return ucwords( strtolower( $name ) );
}

/*
 * Register the filter for example_author_name_uc
 * Argument: the filter you want the function to apply to,
 *           The name of your function
 *           The priority, 10 is default, the higher the priority, the
 *            sooner the filter will be executed. This arguemt is optional
 */
$plug->addfilter( 'filter_comment_author_name', 'example_author_name_uc', 10 );
 
/*
 * Generates a form element on the settings page.
 * Arguments: none, thought some hooks may have a argument
 * Return value: none
 */
function example_about_form()
{
	/* Load globals */	
	global $config, $tpl, $lang;

	/* If the config value doesn't exist, something gone wrong while installing */
	if( !isset( $config['aboutme_text'] ) ) return;

	/* 
	 * The template is seperatet at this point, we just need to load the next
	 *  fragment
	 * On other hook positions you may have to load you own, template with
	 *  tpl->add( 'name.tpl', __LINE__, __FILLE__, './path/to/folder' ); 
	 *  Last three arguments are optional
	 */
	$tpl->part_load();

	/*
	 * Fillin our values. The template engine supports to function for filling
	 * in values, $tpl->fillin_array() takes a array if find => replace pairs,
	 * $tpl->fillin() takes two arguments, first find, second replace.
	 */
	$tpl->fillin_array( array(
		'S_SETTINGS_FORM' => $lang['aboutme_text'],
		'I_SETTINGS_FORM' => '<input type="text" name="aboutme_text" value="' . $config['aboutme_text'] . '" />',
	) );
}

/*
 * Just like $plug->addfilter()
 */
$plug->addhook( 'hook_admin_settings_form', 'example_about_form', 10 );

/*
 * We have the text from your form, now we have to prepare it for saving
 * This is just another hook
 */
function example_about_check()
{
	/* $settings_save contains the values that will be saved to the database here. */
	global $settings_save;
	if( isset( $_POST['aboutme_text'] ) ) $settings_save['aboutme_text'] = $_POST['aboutme_text'];
}
$plug->addhook( 'hook_admin_settings_validating', 'example_about_check' );

/*
 * A widget!
 * Basically, this is just another hook, but it will appear in the sidebar
 */
function example_about_display()
{
	global $tpl, $config, $lang;

	$tpl->part_load();
	
	$tpl->fillin_array( array(
		'S_SIDEBAR_TITLE' => $lang['aboutme_text'],
		'S_SIDEBAR_CONTENT' => $config['aboutme_text'],
	) );
}
$plug->addhook( 'hook_index_sidebar', 'example_about_display', 20 );

?>
